==> DPpackage_1.0-6.tar.gz: DPpackage/src/ToolsSB.f <==
c=======================================================================                  
c=======================================================================                  
c     SUBROUTINES FOR STICK-BREAKING
c=======================================================================                  
c=======================================================================                  

c=======================================================================
      subroutine sickbreaksim(nr,n,alpha,beta,workv,w,v)
c=======================================================================
c     Subroutine to compute the stick breaking weights up to
c     finite level n.
c
c     A.J.V. 2007 
c=======================================================================
      implicit none

c+++++Input
      integer nr,n
      real*8 alpha(nr),beta(nr)

c+++++External working space
      real*8 workv(nr+1)

c+++++Output
      real*8 w(nr),v(nr)

c+++++Internal working space
      integer i 
      real*8 rbeta
      real*8 tmp1,tmp2

c+++++Algorihtm

      workv(1)=0.d0
      tmp1=0.d0
      do i=1,n
         v(i)=rbeta(alpha(i),beta(i)) 
         tmp2=1.d0-v(i)  
         if(i.ne.n)then
            tmp1=tmp1-dlog(tmp2) 
            workv(i+1)=tmp1 
         end if
      end do 
      workv(n+1)=1.0D300

      tmp1=0.d0
      do i=1,n
         w(i)=dexp(-workv(i))-dexp(-workv(i+1))
         tmp1=tmp1+w(i)
      end do  

      do i=1,n
         w(i)=w(i)/tmp1
      end do 

      return
      end

==> DPpackage_1.0-9.tar.gz: DPpackage/src/ToolsSB.f <==
c=======================================================================                  
c=======================================================================                  
c     SUBROUTINES FOR STICK-BREAKING
c=======================================================================                  
c
c      Alejandro Jara
c      Department of Statistics
c      Facultad de Ciencias Fisicas y Matematicas
c      Universidad de Concepcion
c      Avenida Esteban Iturra S/N
c      Barrio Universitario
c      Concepcion
c      Chile
c      Voice: +56-41-2203163  URL  : http://www2.udec.cl/~ajarav
c      Fax  : +56-41-2251529  Email: ajarav@udec.cl
c
c=======================================================================                  

c=======================================================================
      subroutine sickbreaksim(nr,n,alpha,beta,workv,w,v)
c=======================================================================
c     Subroutine to compute the stick breaking weights up to
c     finite level n.
c
c     A.J.V. 2007 
c=======================================================================
      implicit none

c+++++Input
      integer nr,n
      real*8 alpha(nr),beta(nr)

c+++++External working space
      real*8 workv(nr+1)

c+++++Output
      real*8 w(nr),v(nr)

c+++++Internal working space
      integer i 
      real*8 rbeta
      real*8 tmp1,tmp2

c+++++Algorihtm

      workv(1)=0.d0
      tmp1=0.d0
      do i=1,n
         v(i)=rbeta(alpha(i),beta(i)) 
         tmp2=1.d0-v(i)  
         if(i.ne.n)then
            tmp1=tmp1-dlog(tmp2) 
            workv(i+1)=tmp1 
         end if
      end do 
      workv(n+1)=1.0D300

      tmp1=0.d0
      do i=1,n
         w(i)=dexp(-workv(i))-dexp(-workv(i+1))
         tmp1=tmp1+w(i)
      end do  

      do i=1,n
         w(i)=w(i)/tmp1
      end do 

      return
      end

c=======================================================================
      subroutine dpweightsimbl(n,ccluster,alpha,workv,w,v)
c=======================================================================
c     Subroutine to compute the DP weights up to
c     finite level n.
c
c     A.J.V. 2007 
c=======================================================================
      implicit none

c+++++Input
      integer n
      integer ccluster(n)
      real*8 alpha

c+++++External working space
      real*8 workv(n+1)

c+++++Output
      real*8 w(n),v(n)

c+++++Internal working space
      integer i,j,ns 
      real*8 rbeta
      real*8 tmp1,tmp2
      real*8 tmp3
      real*8 tmp5,tmp6
      real*8 tmpv

c+++++Algorihtm

      workv(1)=0.d0
      tmp1=0.d0
      do i=1,n-1
         tmp3=dble(ccluster(i))
         ns=0
         do j=i+1,n
            ns=ns+ccluster(j)
         end do
         tmp5=1.d0+tmp3
         tmp6=alpha+dble(ns) 

         v(i)=rbeta(tmp5,tmp6) 
         tmp2=1.d0-v(i)  
         tmp1=tmp1-dlog(tmp2) 
         workv(i+1)=tmp1 
      end do 
      workv(n+1)=1.0D300

      tmp1=0.d0
      do i=1,n
         w(i)=dexp(-workv(i))-dexp(-workv(i+1))
         tmp1=tmp1+w(i)
      end do  

      do i=1,n
         w(i)=w(i)/tmp1
      end do 

      return
      end
